package xhttp3.internal;

import java.io.Closeable;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Array;
import java.net.IDN;
import java.net.ServerSocket;
import java.net.Socket;
import java.nio.charset.Charset;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Locale;
import java.util.TimeZone;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;
import java.util.regex.Pattern;
import xhttp3.HttpUrl;
import xio.Buffer;
import xio.ByteString;
import xio.Source;

public final class Util {
   public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];
   public static final String[] EMPTY_STRING_ARRAY = new String[0];
   public static final Charset UTF_8 = Charset.forName("UTF-8");
   public static final TimeZone UTC = TimeZone.getTimeZone("GMT");
   private static final Pattern VERIFY_AS_IP_ADDRESS = Pattern.compile("([0-9a-fA-F]*:[0-9a-fA-F:.]*)|([\\d.]+)");

   private Util() {
   }

   public static void checkOffsetAndCount(long arrayLength, long offset, long count) {
      if ((offset | count) < 0L || offset > arrayLength || arrayLength - offset < count) {
         throw new ArrayIndexOutOfBoundsException();
      }
   }

   public static boolean equal(Object a, Object b) {
      return a == b || a != null && a.equals(b);
   }

   public static void closeQuietly(Closeable closeable) {
      if (closeable != null) {
         try {
            closeable.close();
         } catch (RuntimeException var1) {
            throw var1;
         } catch (Exception var2) {
         }
      }

   }

   public static void closeQuietly(Socket socket) {
      if (socket != null) {
         try {
            socket.close();
         } catch (AssertionError var1) {
            if (!isAndroidGetsocknameError(var1)) {
               throw var1;
            }
         } catch (RuntimeException var2) {
            throw var2;
         } catch (Exception var3) {
         }
      }

   }

   public static void closeQuietly(ServerSocket serverSocket) {
      if (serverSocket != null) {
         try {
            serverSocket.close();
         } catch (RuntimeException var1) {
            throw var1;
         } catch (Exception var2) {
         }
      }

   }

   public static void closeAll(Closeable a, Closeable b) {
      Closeable var10000 = a;
      a = null;

      label116:
      try {
         var10000.close();
      } finally {
         break label116;
      }

      boolean var4 = false;

      label112: {
         label111:
         try {
            var4 = true;
            b.close();
            var4 = false;
         } finally {
            if (var4) {
               if (a == null) {
                  break label112;
               }
               break label111;
            }
         }

         b = a;
      }

      if (b != null) {
         if (!(b instanceof IOException)) {
            if (!(b instanceof RuntimeException)) {
               if (b instanceof Error) {
                  throw (Error)b;
               } else {
                  throw new AssertionError(b);
               }
            } else {
               throw (RuntimeException)b;
            }
         } else {
            throw (IOException)b;
         }
      }
   }

   public static boolean discard(Source source, int timeout, TimeUnit timeUnit) {
      try {
         return skipAll(source, timeout, timeUnit);
      } catch (IOException var3) {
         return false;
      }
   }

   public static boolean skipAll(Source param0, int param1, TimeUnit param2) {
      // $FF: Couldn't be decompiled
   }

   public static String md5Hex(String s) {
      Object s1;
      try {
         return ByteString.of(MessageDigest.getInstance("MD5").digest(s.getBytes("UTF-8"))).hex();
      } catch (NoSuchAlgorithmException var1) {
         s1 = var1;
      } catch (UnsupportedEncodingException var2) {
         s1 = var2;
      }

      throw new AssertionError(s1);
   }

   public static String shaBase64(String s) {
      Object s1;
      try {
         return ByteString.of(MessageDigest.getInstance("SHA-1").digest(s.getBytes("UTF-8"))).base64();
      } catch (NoSuchAlgorithmException var1) {
         s1 = var1;
      } catch (UnsupportedEncodingException var2) {
         s1 = var2;
      }

      throw new AssertionError(s1);
   }

   public static ByteString sha1(ByteString s) {
      try {
         return ByteString.of(MessageDigest.getInstance("SHA-1").digest(s.toByteArray()));
      } catch (NoSuchAlgorithmException var1) {
         throw new AssertionError(var1);
      }
   }

   public static ByteString sha256(ByteString s) {
      try {
         return ByteString.of(MessageDigest.getInstance("SHA-256").digest(s.toByteArray()));
      } catch (NoSuchAlgorithmException var1) {
         throw new AssertionError(var1);
      }
   }

   public static <T> List<T> immutableList(List<T> list) {
      return Collections.unmodifiableList(new ArrayList(list));
   }

   public static <T> List<T> immutableList(T... elements) {
      return Collections.unmodifiableList(Arrays.asList((Object[])elements.clone()));
   }

   public static ThreadFactory threadFactory(final String name, final boolean daemon) {
      return new ThreadFactory() {
         public Thread newThread(Runnable runnable) {
            Thread var10000 = new Thread(runnable, name);
            var10000.setDaemon(daemon);
            return var10000;
         }
      };
   }

   public static <T> T[] intersect(Class<T> arrayType, T[] first, T[] second) {
      List var10000 = intersect(first, second);
      return var10000.toArray((Object[])Array.newInstance(arrayType, var10000.size()));
   }

   private static <T> List<T> intersect(T[] first, T[] second) {
      ArrayList var2;
      var2 = new ArrayList.<init>();
      int var3 = first.length;

      for(int var4 = 0; var4 < var3; ++var4) {
         Object var5 = first[var4];
         int var6 = second.length;

         for(int var7 = 0; var7 < var6; ++var7) {
            Object var8;
            if (var5.equals(var8 = second[var7])) {
               var2.add(var8);
               break;
            }
         }
      }

      return var2;
   }

   public static String hostHeader(HttpUrl url, boolean includeDefaultPort) {
      String var2;
      if (url.host().contains(":")) {
         var2 = "[" + url.host() + "]";
      } else {
         var2 = url.host();
      }

      if (includeDefaultPort || url.port() != HttpUrl.defaultPort(url.scheme())) {
         var2 = var2 + ":" + url.port();
      }

      return var2;
   }

   public static String toHumanReadableAscii(String s) {
      int var1 = 0;

      int var3;
      for(int var2 = s.length(); var1 < var2; var1 += Character.charCount(var3)) {
         if ((var3 = s.codePointAt(var1)) <= 31 || var3 >= 127) {
            Buffer var6;
            Buffer var10000 = var6 = new Buffer;
            var10000.<init>();
            var10000.writeUtf8(s, 0, var1);

            while(var1 < var2) {
               int var4;
               int var5;
               if ((var4 = s.codePointAt(var1)) > 31 && var4 < 127) {
                  var5 = var4;
               } else {
                  var5 = 63;
               }

               var6.writeUtf8CodePoint(var5);
               var1 += Character.charCount(var4);
            }

            return var6.readUtf8();
         }
      }

      return s;
   }

   public static boolean isAndroidGetsocknameError(AssertionError e) {
      return e.getCause() != null && e.getMessage() != null && e.getMessage().contains("getsockname failed");
   }

   public static boolean contains(String[] array, String value) {
      return Arrays.asList(array).contains(value);
   }

   public static String[] concat(String[] array, String value) {
      int var2;
      String[] var3;
      String[] var10000 = var3 = new String[var2 = array.length + 1];
      String[] var10003 = array;
      int array1 = array.length;
      System.arraycopy(var10003, 0, var3, 0, array1);
      var10000[var2 - 1] = value;
      return var10000;
   }

   public static int skipLeadingAsciiWhitespace(String input, int pos, int limit) {
      while(pos < limit) {
         char var3;
         if ((var3 = input.charAt(pos)) != '\t' && var3 != '\n' && var3 != '\f' && var3 != '\r' && var3 != ' ') {
            return pos;
         }

         ++pos;
      }

      return limit;
   }

   public static int skipTrailingAsciiWhitespace(String input, int pos, int limit) {
      --limit;

      while(limit >= pos) {
         char var3;
         if ((var3 = input.charAt(limit)) != '\t' && var3 != '\n' && var3 != '\f' && var3 != '\r' && var3 != ' ') {
            return limit + 1;
         }

         --limit;
      }

      return pos;
   }

   public static String trimSubstring(String string, int pos, int limit) {
      int string1;
      return string.substring((int)string, skipTrailingAsciiWhitespace(string, string1 = skipLeadingAsciiWhitespace(string, pos, limit), limit));
   }

   public static int delimiterOffset(String input, int pos, int limit, String delimiters) {
      while(pos < limit) {
         if (delimiters.indexOf(input.charAt(pos)) != -1) {
            return pos;
         }

         ++pos;
      }

      return limit;
   }

   public static int delimiterOffset(String input, int pos, int limit, char delimiter) {
      while(pos < limit) {
         if (input.charAt(pos) == delimiter) {
            return pos;
         }

         ++pos;
      }

      return limit;
   }

   public static String domainToAscii(String input) {
      String var10000;
      boolean var10001;
      try {
         var10000 = IDN.toASCII(input).toLowerCase(Locale.US);
      } catch (IllegalArgumentException var3) {
         var10001 = false;
         return null;
      }

      input = var10000;

      boolean var4;
      try {
         var4 = var10000.isEmpty();
      } catch (IllegalArgumentException var2) {
         var10001 = false;
         return null;
      }

      if (var4) {
         return null;
      } else {
         try {
            var4 = containsInvalidHostnameAsciiCodes(input);
         } catch (IllegalArgumentException var1) {
            var10001 = false;
            return null;
         }

         if (var4) {
            return null;
         } else {
            return input;
         }
      }
   }

   private static boolean containsInvalidHostnameAsciiCodes(String hostnameAscii) {
      for(int var1 = 0; var1 < hostnameAscii.length(); ++var1) {
         char var2;
         if ((var2 = hostnameAscii.charAt(var1)) <= 31 || var2 >= 127) {
            return true;
         }

         if (" #%/:?@[\\]".indexOf(var2) != -1) {
            return true;
         }
      }

      return false;
   }

   public static boolean verifyAsIpAddress(String host) {
      return VERIFY_AS_IP_ADDRESS.matcher(host).matches();
   }

   public static String format(String format, Object... args) {
      return String.format(Locale.US, format, args);
   }
}
